YARP 2.1.7 (2007-09-25)                                                {#v2_1_7}
=======================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.1.6...v2.1.7`):

```
    67	Paul Fitzpatrick <paulfitz@alum.mit.edu>
    20	Giacomo Spigler <spiglerg@gmail.com>
     4	Carlos Beltran-Gonzalez <carlos.beltran@iit.it>
     3	Alexandre Bernardino <alex@isr.ist.utl.pt>
     1	Alessandro Scalzo <alessandro.scalzo@iit.it>
```
